package sun.management.snmp.jvmmib;

import javax.management.MBeanServer;
import com.sun.jmx.snmp.agent.SnmpMibTable;
import com.sun.jmx.snmp.agent.SnmpMibSubRequest;
import com.sun.jmx.snmp.SnmpStatusException;
import com.sun.jmx.snmp.SnmpGauge;
import com.sun.jmx.snmp.SnmpCounter;
import com.sun.jmx.snmp.SnmpCounter64;
import com.sun.jmx.snmp.SnmpInt;
import com.sun.jmx.snmp.SnmpValue;
import com.sun.jmx.snmp.agent.SnmpMib;
import com.sun.jmx.snmp.agent.SnmpStandardObjectServer;
import com.sun.jmx.snmp.agent.SnmpStandardMetaServer;
import java.io.Serializable;
import com.sun.jmx.snmp.agent.SnmpMibGroup;

public class JvmThreadingMeta extends SnmpMibGroup implements Serializable, SnmpStandardMetaServer
{
    static final long serialVersionUID = 5223833578005322854L;
    protected JvmThreadingMBean node;
    protected SnmpStandardObjectServer objectserver;
    protected JvmThreadInstanceTableMeta tableJvmThreadInstanceTable;
    
    public JvmThreadingMeta(SnmpMib snmpMib, SnmpStandardObjectServer objectserver) {
        this.objectserver = null;
        this.tableJvmThreadInstanceTable = null;
        this.objectserver = objectserver;
        try {
            this.registerObject(6L);
            this.registerObject(5L);
            this.registerObject(4L);
            this.registerObject(3L);
            this.registerObject(2L);
            this.registerObject(1L);
            this.registerObject(10L);
            this.registerObject(7L);
        }
        catch (IllegalAccessException ex) {
            throw new RuntimeException(ex.getMessage());
        }
    }
    
    public SnmpValue get(long n, Object o) throws SnmpStatusException {
        switch ((int)n) {
            case 6: {
                return new SnmpInt(this.node.getJvmThreadCpuTimeMonitoring());
            }
            case 5: {
                return new SnmpInt(this.node.getJvmThreadContentionMonitoring());
            }
            case 4: {
                return new SnmpCounter64(this.node.getJvmThreadTotalStartedCount());
            }
            case 3: {
                return new SnmpCounter(this.node.getJvmThreadPeakCount());
            }
            case 2: {
                return new SnmpGauge(this.node.getJvmThreadDaemonCount());
            }
            case 1: {
                return new SnmpGauge(this.node.getJvmThreadCount());
            }
            case 10: {
                throw new SnmpStatusException(224);
            }
            case 7: {
                return new SnmpCounter64(this.node.getJvmThreadPeakCountReset());
            }
            default: {
                throw new SnmpStatusException(225);
            }
        }
    }
    
    public SnmpValue set(SnmpValue snmpValue, long n, Object o) throws SnmpStatusException {
        switch ((int)n) {
            case 6: {
                if ((snmpValue instanceof SnmpInt)) {
                    try {
                        this.node.setJvmThreadCpuTimeMonitoring(new EnumJvmThreadCpuTimeMonitoring(((SnmpInt)snmpValue).toInteger()));
                    }
                    catch (IllegalArgumentException ex) {
                        throw new SnmpStatusException(10);
                    }
                    return new SnmpInt(this.node.getJvmThreadCpuTimeMonitoring());
                }
                throw new SnmpStatusException(7);
            }
            case 5: {
                if ((snmpValue instanceof SnmpInt)) {
                    try {
                        this.node.setJvmThreadContentionMonitoring(new EnumJvmThreadContentionMonitoring(((SnmpInt)snmpValue).toInteger()));
                    }
                    catch (IllegalArgumentException ex2) {
                        throw new SnmpStatusException(10);
                    }
                    return new SnmpInt(this.node.getJvmThreadContentionMonitoring());
                }
                throw new SnmpStatusException(7);
            }
            case 4: {
                throw new SnmpStatusException(17);
            }
            case 3: {
                throw new SnmpStatusException(17);
            }
            case 2: {
                throw new SnmpStatusException(17);
            }
            case 1: {
                throw new SnmpStatusException(17);
            }
            case 10: {
                throw new SnmpStatusException(17);
            }
            case 7: {
                if ((snmpValue instanceof SnmpCounter64)) {
                    this.node.setJvmThreadPeakCountReset(((SnmpCounter64)snmpValue).toLong());
                    return new SnmpCounter64(this.node.getJvmThreadPeakCountReset());
                }
                throw new SnmpStatusException(7);
            }
            default: {
                throw new SnmpStatusException(17);
            }
        }
    }
    
    public void check(SnmpValue snmpValue, long n, Object o) throws SnmpStatusException {
        switch ((int)n) {
            case 6: {
                if ((snmpValue instanceof SnmpInt)) {
                    try {
                        this.node.checkJvmThreadCpuTimeMonitoring(new EnumJvmThreadCpuTimeMonitoring(((SnmpInt)snmpValue).toInteger()));
                        break;
                    }
                    catch (IllegalArgumentException ex) {
                        throw new SnmpStatusException(10);
                    }
                }
                else {
                    throw new SnmpStatusException(7);
                }
            }
            case 5: {
                if ((snmpValue instanceof SnmpInt)) {
                    try {
                        this.node.checkJvmThreadContentionMonitoring(new EnumJvmThreadContentionMonitoring(((SnmpInt)snmpValue).toInteger()));
                        break;
                    }
                    catch (IllegalArgumentException ex2) {
                        throw new SnmpStatusException(10);
                    }
                }
                else {
                    throw new SnmpStatusException(7);
                }
            }
            case 4: {
                throw new SnmpStatusException(17);
            }
            case 3: {
                throw new SnmpStatusException(17);
            }
            case 2: {
                throw new SnmpStatusException(17);
            }
            case 1: {
                throw new SnmpStatusException(17);
            }
            case 10: {
                throw new SnmpStatusException(17);
            }
            case 7: {
                if ((snmpValue instanceof SnmpCounter64)) {
                    this.node.checkJvmThreadPeakCountReset(((SnmpCounter64)snmpValue).toLong());
                    break;
                }
                throw new SnmpStatusException(7);
            }
            default: {
                throw new SnmpStatusException(17);
            }
        }
    }
    
    protected void setInstance(JvmThreadingMBean node) {
        this.node = node;
    }
    
    public void get(SnmpMibSubRequest snmpMibSubRequest, int n) throws SnmpStatusException {
        this.objectserver.get(this, snmpMibSubRequest, n);
    }
    
    public void set(SnmpMibSubRequest snmpMibSubRequest, int n) throws SnmpStatusException {
        this.objectserver.set(this, snmpMibSubRequest, n);
    }
    
    public void check(SnmpMibSubRequest snmpMibSubRequest, int n) throws SnmpStatusException {
        this.objectserver.check(this, snmpMibSubRequest, n);
    }
    
    public boolean isVariable(long n) {
        switch ((int)n) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7: {
                return true;
            }
            default: {
                return false;
            }
        }
    }
    
    public boolean isReadable(long n) {
        switch ((int)n) {
            case 1:
            case 2:
            case 3:
            case 4:
            case 5:
            case 6:
            case 7: {
                return true;
            }
            default: {
                return false;
            }
        }
    }
    
    public boolean skipVariable(long n, Object o, int n2) {
        switch ((int)n) {
            case 4:
            case 7: {
                if (n2 == 0) {
                    return true;
                }
                break;
            }
        }
        return super.skipVariable(n, o, n2);
    }
    
    public String getAttributeName(long n) throws SnmpStatusException {
        switch ((int)n) {
            case 6: {
                return "JvmThreadCpuTimeMonitoring";
            }
            case 5: {
                return "JvmThreadContentionMonitoring";
            }
            case 4: {
                return "JvmThreadTotalStartedCount";
            }
            case 3: {
                return "JvmThreadPeakCount";
            }
            case 2: {
                return "JvmThreadDaemonCount";
            }
            case 1: {
                return "JvmThreadCount";
            }
            case 10: {
                throw new SnmpStatusException(224);
            }
            case 7: {
                return "JvmThreadPeakCountReset";
            }
            default: {
                throw new SnmpStatusException(225);
            }
        }
    }
    
    public boolean isTable(long n) {
        switch ((int)n) {
            case 10: {
                return true;
            }
            default: {
                return false;
            }
        }
    }
    
    public SnmpMibTable getTable(long n) {
        switch ((int)n) {
            case 10: {
                return this.tableJvmThreadInstanceTable;
            }
            default: {
                return null;
            }
        }
    }
    
    public void registerTableNodes(SnmpMib snmpMib, MBeanServer mBeanServer) {
        this.tableJvmThreadInstanceTable = this.createJvmThreadInstanceTableMetaNode("JvmThreadInstanceTable", "JvmThreading", snmpMib, mBeanServer);
        if (this.tableJvmThreadInstanceTable != null) {
            this.tableJvmThreadInstanceTable.registerEntryNode(snmpMib, mBeanServer);
            snmpMib.registerTableMeta("JvmThreadInstanceTable", this.tableJvmThreadInstanceTable);
        }
    }
    
    protected JvmThreadInstanceTableMeta createJvmThreadInstanceTableMetaNode(String s, String s2, SnmpMib snmpMib, MBeanServer mBeanServer) {
        return new JvmThreadInstanceTableMeta(snmpMib, this.objectserver);
    }
}
